RewardItem class
Credit information about a reward received from a RewardedAd or
RewardedInterstitialAd.
Constructors
- RewardItem(num amount, String type)
- Default constructor for RewardItem.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited